/*
 * Copyright (c) 1993 Addison-Wesley Publishing Company.
 * All rights reserved.  This source code is provided
 * for its instructional value, and is not guaranteed
 * for any particular purpose.
 */
#include <sys/types.h>
#include <stdio.h>
#include <netconfig.h>
#include <netdir.h>
#include <tiuser.h>

extern int initclient(char *);
extern int connect(int, char *, uint_t);

int
conn(char *host, char *service)
{
	void *p;
	int i, fd;
	struct netconfig *ncp;
	struct nd_hostserv hs;
	struct nd_addrlist *alp;
	struct netbuf *np;

	/*
	 * Gain access to /etc/netconfig.
	 */
	if ((p = setnetpath()) == NULL)
		return(-1);

	/*
	 * Check all networks using connection-oriented
	 * protocols specified by NETPATH.
	 */
	hs.h_host = host;
	hs.h_serv = service;
	while ((ncp = getnetpath(p)) != NULL) {
		if ((ncp->nc_semantics != NC_TPI_COTS) &&
		  (ncp->nc_semantics != NC_TPI_COTS_ORD))
			continue;

		/*
		 * Convert the requested host and service
		 * to a list of addresses.
		 */
		if (netdir_getbyname(ncp, &hs, &alp) != 0)
			continue;

		/*
		 * Get a transport endpoint.  initclient
		 * is from Example 4.2.1.
		 */
		if ((fd = initclient(ncp->nc_device)) < 0) {
			netdir_free((void *)alp, ND_ADDRLIST);
			continue;
		}

		/*
		 * Try to connect to one of the addresses.
		 * connect is from Example 4.4.1.
		 */
		np = alp->n_addrs;
		for (i = 0; i < alp->n_cnt; i++, np++) {
			if (connect(fd, np->buf, np->len) == 0) {

				/*
				 * We've got a connection.  Clean
				 * up and return.
				 */
				netdir_free((void *)alp, ND_ADDRLIST);
				endnetpath(p);
				return(fd);
			}
		}

		/*
		 * Not able to connect to any of the addresses.
		 * Clean up and continue checking other networks.
		 */
		netdir_free((void *)alp, ND_ADDRLIST);
		t_close(fd);
	}

	/*
	 * Not able to connect to the given host and service.
	 * Clean up and return.
	 */
	endnetpath(p);
	return(-1);
}
