/*
 * Copyright (c) 1993 Addison-Wesley Publishing Company.
 * All rights reserved.  This source code is provided
 * for its instructional value, and is not guaranteed
 * for any particular purpose.
 */
#include <sys/utsname.h>
#include <rpc/rpc.h>
#include <stdio.h>
#include <stdlib.h>
#include "runame.h"

void
main(int argc, char *argv[])
{
	enum clnt_stat status;
	struct utsname u;
	CLIENT *handle;
	struct timeval t;
	char buf[64];

	if (argc != 2) {
		fprintf(stderr, "usage: %s hostname\n", argv[0]);
		exit(1);
	}

	/*
	 * Create the client handle.
	 */
	handle = clnt_create(argv[1], UNAME_PROG, UNAME_VER,
	  "netpath");
	if (handle == NULL) {
		fprintf(stderr,
		  "%s: can't create client handle: %s\n",
		  argv[0], clnt_spcreateerror(""));
		exit(1);
	}

	/*
	 * Use a 10-second timeout.
	 */
	t.tv_sec = 10;
	t.tv_usec = 0;

	/*
	 * Make the remote procedure call.
	 */
	status = clnt_call(handle, UNAME_PROC, xdr_void, NULL,
	  xdr_utsname, (char *)&u, t);
	if (status == RPC_SUCCESS) {
		/*
		 * RPC succeeded.  Print the strings returned.
		 */
		printf("sysname is %s\n", u.sysname);
		printf("nodename is %s\n", u.nodename);
		printf("release is %s\n", u.release);
		printf("version is %s\n", u.version);
		printf("machine type is %s\n", u.machine);
		exit(0);
	} else {
		/*
		 * RPC failed.  Print an error message.
		 */
		sprintf(buf, "%s: rpc failed", argv[0]);
		clnt_perror(handle, buf);
		exit(1);
	}
}
